# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.3.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKLabelMapPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _itkLabelStatisticsOpeningImageFilterPython
else:
    import _itkLabelStatisticsOpeningImageFilterPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.itkImagePython
import itk.itkSizePython
import itk.pyBasePython
import itk.itkMatrixPython
import itk.itkPointPython
import itk.vnl_vectorPython
import itk.vnl_matrixPython
import itk.stdcomplexPython
import itk.itkFixedArrayPython
import itk.vnl_vector_refPython
import itk.itkVectorPython
import itk.vnl_matrix_fixedPython
import itk.itkCovariantVectorPython
import itk.itkOffsetPython
import itk.itkRGBAPixelPython
import itk.itkSymmetricSecondRankTensorPython
import itk.itkIndexPython
import itk.itkRGBPixelPython
import itk.itkImageRegionPython
import itk.ITKCommonBasePython
import itk.itkImageToImageFilterAPython
import itk.itkImageToImageFilterCommonPython
import itk.itkImageSourcePython
import itk.itkImageSourceCommonPython
import itk.itkVectorImagePython
import itk.itkVariableLengthVectorPython
import itk.itkPhasedArray3DSpecialCoordinatesImagePython

def itkLabelStatisticsOpeningImageFilterIUC2IF2_New():
    return itkLabelStatisticsOpeningImageFilterIUC2IF2.New()

class itkLabelStatisticsOpeningImageFilterIUC2IF2(itk.itkImageToImageFilterAPython.itkImageToImageFilterIUC2IUC2):
    r"""Proxy of C++ itkLabelStatisticsOpeningImageFilterIUC2IF2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkLabelStatisticsOpeningImageFilterIUC2IF2_Pointer"""
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC2IF2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkLabelStatisticsOpeningImageFilterIUC2IF2_Pointer"""
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC2IF2_Clone(self)
    InputEqualityComparableCheck = _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC2IF2_InputEqualityComparableCheck
    
    IntConvertibleToInputCheck = _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC2IF2_IntConvertibleToInputCheck
    
    InputOStreamWritableCheck = _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC2IF2_InputOStreamWritableCheck
    

    def SetBackgroundValue(self, _arg):
        r"""
        SetBackgroundValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC2IF2_SetBackgroundValue(self, _arg)

    def GetBackgroundValue(self):
        r"""GetBackgroundValue(self) -> unsigned char"""
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC2IF2_GetBackgroundValue(self)

    def GetLambda(self):
        r"""GetLambda(self) -> double"""
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC2IF2_GetLambda(self)

    def SetLambda(self, _arg):
        r"""
        SetLambda(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC2IF2_SetLambda(self, _arg)

    def GetReverseOrdering(self):
        r"""GetReverseOrdering(self) -> bool"""
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC2IF2_GetReverseOrdering(self)

    def SetReverseOrdering(self, _arg):
        r"""
        SetReverseOrdering(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC2IF2_SetReverseOrdering(self, _arg)

    def ReverseOrderingOn(self):
        r"""ReverseOrderingOn(self)"""
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC2IF2_ReverseOrderingOn(self)

    def ReverseOrderingOff(self):
        r"""ReverseOrderingOff(self)"""
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC2IF2_ReverseOrderingOff(self)

    def GetAttribute(self):
        r"""GetAttribute(self) -> unsigned int"""
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC2IF2_GetAttribute(self)

    def SetAttribute(self, *args):
        r"""
        SetAttribute(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        SetAttribute(self, s)

        Parameters
        ----------
        s: std::string const &

        """
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC2IF2_SetAttribute(self, *args)

    def SetFeatureImage(self, input):
        r"""
        SetFeatureImage(self, input)

        Parameters
        ----------
        input: itkImageF2 const *

        """
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC2IF2_SetFeatureImage(self, input)

    def GetFeatureImage(self):
        r"""GetFeatureImage(self) -> itkImageF2"""
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC2IF2_GetFeatureImage(self)

    def SetInput1(self, input):
        r"""
        SetInput1(self, input)

        Parameters
        ----------
        input: itkImageUC2 const *

        """
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC2IF2_SetInput1(self, input)

    def SetInput2(self, input):
        r"""
        SetInput2(self, input)

        Parameters
        ----------
        input: itkImageF2 const *

        """
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC2IF2_SetInput2(self, input)
    __swig_destroy__ = _itkLabelStatisticsOpeningImageFilterPython.delete_itkLabelStatisticsOpeningImageFilterIUC2IF2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkLabelStatisticsOpeningImageFilterIUC2IF2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC2IF2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkLabelStatisticsOpeningImageFilterIUC2IF2

        Create a new object of the class itkLabelStatisticsOpeningImageFilterIUC2IF2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkLabelStatisticsOpeningImageFilterIUC2IF2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkLabelStatisticsOpeningImageFilterIUC2IF2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkLabelStatisticsOpeningImageFilterIUC2IF2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkLabelStatisticsOpeningImageFilterIUC2IF2 in _itkLabelStatisticsOpeningImageFilterPython:
_itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC2IF2_swigregister(itkLabelStatisticsOpeningImageFilterIUC2IF2)

def itkLabelStatisticsOpeningImageFilterIUC2ISS2_New():
    return itkLabelStatisticsOpeningImageFilterIUC2ISS2.New()

class itkLabelStatisticsOpeningImageFilterIUC2ISS2(itk.itkImageToImageFilterAPython.itkImageToImageFilterIUC2IUC2):
    r"""Proxy of C++ itkLabelStatisticsOpeningImageFilterIUC2ISS2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkLabelStatisticsOpeningImageFilterIUC2ISS2_Pointer"""
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC2ISS2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkLabelStatisticsOpeningImageFilterIUC2ISS2_Pointer"""
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC2ISS2_Clone(self)
    InputEqualityComparableCheck = _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC2ISS2_InputEqualityComparableCheck
    
    IntConvertibleToInputCheck = _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC2ISS2_IntConvertibleToInputCheck
    
    InputOStreamWritableCheck = _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC2ISS2_InputOStreamWritableCheck
    

    def SetBackgroundValue(self, _arg):
        r"""
        SetBackgroundValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC2ISS2_SetBackgroundValue(self, _arg)

    def GetBackgroundValue(self):
        r"""GetBackgroundValue(self) -> unsigned char"""
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC2ISS2_GetBackgroundValue(self)

    def GetLambda(self):
        r"""GetLambda(self) -> double"""
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC2ISS2_GetLambda(self)

    def SetLambda(self, _arg):
        r"""
        SetLambda(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC2ISS2_SetLambda(self, _arg)

    def GetReverseOrdering(self):
        r"""GetReverseOrdering(self) -> bool"""
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC2ISS2_GetReverseOrdering(self)

    def SetReverseOrdering(self, _arg):
        r"""
        SetReverseOrdering(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC2ISS2_SetReverseOrdering(self, _arg)

    def ReverseOrderingOn(self):
        r"""ReverseOrderingOn(self)"""
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC2ISS2_ReverseOrderingOn(self)

    def ReverseOrderingOff(self):
        r"""ReverseOrderingOff(self)"""
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC2ISS2_ReverseOrderingOff(self)

    def GetAttribute(self):
        r"""GetAttribute(self) -> unsigned int"""
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC2ISS2_GetAttribute(self)

    def SetAttribute(self, *args):
        r"""
        SetAttribute(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        SetAttribute(self, s)

        Parameters
        ----------
        s: std::string const &

        """
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC2ISS2_SetAttribute(self, *args)

    def SetFeatureImage(self, input):
        r"""
        SetFeatureImage(self, input)

        Parameters
        ----------
        input: itkImageSS2 const *

        """
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC2ISS2_SetFeatureImage(self, input)

    def GetFeatureImage(self):
        r"""GetFeatureImage(self) -> itkImageSS2"""
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC2ISS2_GetFeatureImage(self)

    def SetInput1(self, input):
        r"""
        SetInput1(self, input)

        Parameters
        ----------
        input: itkImageUC2 const *

        """
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC2ISS2_SetInput1(self, input)

    def SetInput2(self, input):
        r"""
        SetInput2(self, input)

        Parameters
        ----------
        input: itkImageSS2 const *

        """
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC2ISS2_SetInput2(self, input)
    __swig_destroy__ = _itkLabelStatisticsOpeningImageFilterPython.delete_itkLabelStatisticsOpeningImageFilterIUC2ISS2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkLabelStatisticsOpeningImageFilterIUC2ISS2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC2ISS2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkLabelStatisticsOpeningImageFilterIUC2ISS2

        Create a new object of the class itkLabelStatisticsOpeningImageFilterIUC2ISS2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkLabelStatisticsOpeningImageFilterIUC2ISS2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkLabelStatisticsOpeningImageFilterIUC2ISS2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkLabelStatisticsOpeningImageFilterIUC2ISS2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkLabelStatisticsOpeningImageFilterIUC2ISS2 in _itkLabelStatisticsOpeningImageFilterPython:
_itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC2ISS2_swigregister(itkLabelStatisticsOpeningImageFilterIUC2ISS2)

def itkLabelStatisticsOpeningImageFilterIUC2IUC2_New():
    return itkLabelStatisticsOpeningImageFilterIUC2IUC2.New()

class itkLabelStatisticsOpeningImageFilterIUC2IUC2(itk.itkImageToImageFilterAPython.itkImageToImageFilterIUC2IUC2):
    r"""Proxy of C++ itkLabelStatisticsOpeningImageFilterIUC2IUC2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkLabelStatisticsOpeningImageFilterIUC2IUC2_Pointer"""
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC2IUC2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkLabelStatisticsOpeningImageFilterIUC2IUC2_Pointer"""
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC2IUC2_Clone(self)
    InputEqualityComparableCheck = _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC2IUC2_InputEqualityComparableCheck
    
    IntConvertibleToInputCheck = _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC2IUC2_IntConvertibleToInputCheck
    
    InputOStreamWritableCheck = _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC2IUC2_InputOStreamWritableCheck
    

    def SetBackgroundValue(self, _arg):
        r"""
        SetBackgroundValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC2IUC2_SetBackgroundValue(self, _arg)

    def GetBackgroundValue(self):
        r"""GetBackgroundValue(self) -> unsigned char"""
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC2IUC2_GetBackgroundValue(self)

    def GetLambda(self):
        r"""GetLambda(self) -> double"""
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC2IUC2_GetLambda(self)

    def SetLambda(self, _arg):
        r"""
        SetLambda(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC2IUC2_SetLambda(self, _arg)

    def GetReverseOrdering(self):
        r"""GetReverseOrdering(self) -> bool"""
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC2IUC2_GetReverseOrdering(self)

    def SetReverseOrdering(self, _arg):
        r"""
        SetReverseOrdering(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC2IUC2_SetReverseOrdering(self, _arg)

    def ReverseOrderingOn(self):
        r"""ReverseOrderingOn(self)"""
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC2IUC2_ReverseOrderingOn(self)

    def ReverseOrderingOff(self):
        r"""ReverseOrderingOff(self)"""
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC2IUC2_ReverseOrderingOff(self)

    def GetAttribute(self):
        r"""GetAttribute(self) -> unsigned int"""
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC2IUC2_GetAttribute(self)

    def SetAttribute(self, *args):
        r"""
        SetAttribute(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        SetAttribute(self, s)

        Parameters
        ----------
        s: std::string const &

        """
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC2IUC2_SetAttribute(self, *args)

    def SetFeatureImage(self, input):
        r"""
        SetFeatureImage(self, input)

        Parameters
        ----------
        input: itkImageUC2 const *

        """
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC2IUC2_SetFeatureImage(self, input)

    def GetFeatureImage(self):
        r"""GetFeatureImage(self) -> itkImageUC2"""
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC2IUC2_GetFeatureImage(self)

    def SetInput1(self, input):
        r"""
        SetInput1(self, input)

        Parameters
        ----------
        input: itkImageUC2 const *

        """
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC2IUC2_SetInput1(self, input)

    def SetInput2(self, input):
        r"""
        SetInput2(self, input)

        Parameters
        ----------
        input: itkImageUC2 const *

        """
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC2IUC2_SetInput2(self, input)
    __swig_destroy__ = _itkLabelStatisticsOpeningImageFilterPython.delete_itkLabelStatisticsOpeningImageFilterIUC2IUC2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkLabelStatisticsOpeningImageFilterIUC2IUC2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC2IUC2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkLabelStatisticsOpeningImageFilterIUC2IUC2

        Create a new object of the class itkLabelStatisticsOpeningImageFilterIUC2IUC2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkLabelStatisticsOpeningImageFilterIUC2IUC2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkLabelStatisticsOpeningImageFilterIUC2IUC2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkLabelStatisticsOpeningImageFilterIUC2IUC2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkLabelStatisticsOpeningImageFilterIUC2IUC2 in _itkLabelStatisticsOpeningImageFilterPython:
_itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC2IUC2_swigregister(itkLabelStatisticsOpeningImageFilterIUC2IUC2)

def itkLabelStatisticsOpeningImageFilterIUC3IF3_New():
    return itkLabelStatisticsOpeningImageFilterIUC3IF3.New()

class itkLabelStatisticsOpeningImageFilterIUC3IF3(itk.itkImageToImageFilterAPython.itkImageToImageFilterIUC3IUC3):
    r"""Proxy of C++ itkLabelStatisticsOpeningImageFilterIUC3IF3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkLabelStatisticsOpeningImageFilterIUC3IF3_Pointer"""
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC3IF3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkLabelStatisticsOpeningImageFilterIUC3IF3_Pointer"""
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC3IF3_Clone(self)
    InputEqualityComparableCheck = _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC3IF3_InputEqualityComparableCheck
    
    IntConvertibleToInputCheck = _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC3IF3_IntConvertibleToInputCheck
    
    InputOStreamWritableCheck = _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC3IF3_InputOStreamWritableCheck
    

    def SetBackgroundValue(self, _arg):
        r"""
        SetBackgroundValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC3IF3_SetBackgroundValue(self, _arg)

    def GetBackgroundValue(self):
        r"""GetBackgroundValue(self) -> unsigned char"""
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC3IF3_GetBackgroundValue(self)

    def GetLambda(self):
        r"""GetLambda(self) -> double"""
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC3IF3_GetLambda(self)

    def SetLambda(self, _arg):
        r"""
        SetLambda(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC3IF3_SetLambda(self, _arg)

    def GetReverseOrdering(self):
        r"""GetReverseOrdering(self) -> bool"""
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC3IF3_GetReverseOrdering(self)

    def SetReverseOrdering(self, _arg):
        r"""
        SetReverseOrdering(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC3IF3_SetReverseOrdering(self, _arg)

    def ReverseOrderingOn(self):
        r"""ReverseOrderingOn(self)"""
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC3IF3_ReverseOrderingOn(self)

    def ReverseOrderingOff(self):
        r"""ReverseOrderingOff(self)"""
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC3IF3_ReverseOrderingOff(self)

    def GetAttribute(self):
        r"""GetAttribute(self) -> unsigned int"""
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC3IF3_GetAttribute(self)

    def SetAttribute(self, *args):
        r"""
        SetAttribute(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        SetAttribute(self, s)

        Parameters
        ----------
        s: std::string const &

        """
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC3IF3_SetAttribute(self, *args)

    def SetFeatureImage(self, input):
        r"""
        SetFeatureImage(self, input)

        Parameters
        ----------
        input: itkImageF3 const *

        """
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC3IF3_SetFeatureImage(self, input)

    def GetFeatureImage(self):
        r"""GetFeatureImage(self) -> itkImageF3"""
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC3IF3_GetFeatureImage(self)

    def SetInput1(self, input):
        r"""
        SetInput1(self, input)

        Parameters
        ----------
        input: itkImageUC3 const *

        """
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC3IF3_SetInput1(self, input)

    def SetInput2(self, input):
        r"""
        SetInput2(self, input)

        Parameters
        ----------
        input: itkImageF3 const *

        """
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC3IF3_SetInput2(self, input)
    __swig_destroy__ = _itkLabelStatisticsOpeningImageFilterPython.delete_itkLabelStatisticsOpeningImageFilterIUC3IF3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkLabelStatisticsOpeningImageFilterIUC3IF3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC3IF3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkLabelStatisticsOpeningImageFilterIUC3IF3

        Create a new object of the class itkLabelStatisticsOpeningImageFilterIUC3IF3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkLabelStatisticsOpeningImageFilterIUC3IF3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkLabelStatisticsOpeningImageFilterIUC3IF3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkLabelStatisticsOpeningImageFilterIUC3IF3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkLabelStatisticsOpeningImageFilterIUC3IF3 in _itkLabelStatisticsOpeningImageFilterPython:
_itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC3IF3_swigregister(itkLabelStatisticsOpeningImageFilterIUC3IF3)

def itkLabelStatisticsOpeningImageFilterIUC3ISS3_New():
    return itkLabelStatisticsOpeningImageFilterIUC3ISS3.New()

class itkLabelStatisticsOpeningImageFilterIUC3ISS3(itk.itkImageToImageFilterAPython.itkImageToImageFilterIUC3IUC3):
    r"""Proxy of C++ itkLabelStatisticsOpeningImageFilterIUC3ISS3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkLabelStatisticsOpeningImageFilterIUC3ISS3_Pointer"""
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC3ISS3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkLabelStatisticsOpeningImageFilterIUC3ISS3_Pointer"""
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC3ISS3_Clone(self)
    InputEqualityComparableCheck = _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC3ISS3_InputEqualityComparableCheck
    
    IntConvertibleToInputCheck = _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC3ISS3_IntConvertibleToInputCheck
    
    InputOStreamWritableCheck = _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC3ISS3_InputOStreamWritableCheck
    

    def SetBackgroundValue(self, _arg):
        r"""
        SetBackgroundValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC3ISS3_SetBackgroundValue(self, _arg)

    def GetBackgroundValue(self):
        r"""GetBackgroundValue(self) -> unsigned char"""
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC3ISS3_GetBackgroundValue(self)

    def GetLambda(self):
        r"""GetLambda(self) -> double"""
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC3ISS3_GetLambda(self)

    def SetLambda(self, _arg):
        r"""
        SetLambda(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC3ISS3_SetLambda(self, _arg)

    def GetReverseOrdering(self):
        r"""GetReverseOrdering(self) -> bool"""
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC3ISS3_GetReverseOrdering(self)

    def SetReverseOrdering(self, _arg):
        r"""
        SetReverseOrdering(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC3ISS3_SetReverseOrdering(self, _arg)

    def ReverseOrderingOn(self):
        r"""ReverseOrderingOn(self)"""
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC3ISS3_ReverseOrderingOn(self)

    def ReverseOrderingOff(self):
        r"""ReverseOrderingOff(self)"""
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC3ISS3_ReverseOrderingOff(self)

    def GetAttribute(self):
        r"""GetAttribute(self) -> unsigned int"""
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC3ISS3_GetAttribute(self)

    def SetAttribute(self, *args):
        r"""
        SetAttribute(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        SetAttribute(self, s)

        Parameters
        ----------
        s: std::string const &

        """
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC3ISS3_SetAttribute(self, *args)

    def SetFeatureImage(self, input):
        r"""
        SetFeatureImage(self, input)

        Parameters
        ----------
        input: itkImageSS3 const *

        """
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC3ISS3_SetFeatureImage(self, input)

    def GetFeatureImage(self):
        r"""GetFeatureImage(self) -> itkImageSS3"""
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC3ISS3_GetFeatureImage(self)

    def SetInput1(self, input):
        r"""
        SetInput1(self, input)

        Parameters
        ----------
        input: itkImageUC3 const *

        """
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC3ISS3_SetInput1(self, input)

    def SetInput2(self, input):
        r"""
        SetInput2(self, input)

        Parameters
        ----------
        input: itkImageSS3 const *

        """
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC3ISS3_SetInput2(self, input)
    __swig_destroy__ = _itkLabelStatisticsOpeningImageFilterPython.delete_itkLabelStatisticsOpeningImageFilterIUC3ISS3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkLabelStatisticsOpeningImageFilterIUC3ISS3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC3ISS3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkLabelStatisticsOpeningImageFilterIUC3ISS3

        Create a new object of the class itkLabelStatisticsOpeningImageFilterIUC3ISS3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkLabelStatisticsOpeningImageFilterIUC3ISS3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkLabelStatisticsOpeningImageFilterIUC3ISS3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkLabelStatisticsOpeningImageFilterIUC3ISS3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkLabelStatisticsOpeningImageFilterIUC3ISS3 in _itkLabelStatisticsOpeningImageFilterPython:
_itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC3ISS3_swigregister(itkLabelStatisticsOpeningImageFilterIUC3ISS3)

def itkLabelStatisticsOpeningImageFilterIUC3IUC3_New():
    return itkLabelStatisticsOpeningImageFilterIUC3IUC3.New()

class itkLabelStatisticsOpeningImageFilterIUC3IUC3(itk.itkImageToImageFilterAPython.itkImageToImageFilterIUC3IUC3):
    r"""Proxy of C++ itkLabelStatisticsOpeningImageFilterIUC3IUC3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkLabelStatisticsOpeningImageFilterIUC3IUC3_Pointer"""
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC3IUC3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkLabelStatisticsOpeningImageFilterIUC3IUC3_Pointer"""
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC3IUC3_Clone(self)
    InputEqualityComparableCheck = _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC3IUC3_InputEqualityComparableCheck
    
    IntConvertibleToInputCheck = _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC3IUC3_IntConvertibleToInputCheck
    
    InputOStreamWritableCheck = _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC3IUC3_InputOStreamWritableCheck
    

    def SetBackgroundValue(self, _arg):
        r"""
        SetBackgroundValue(self, _arg)

        Parameters
        ----------
        _arg: unsigned char

        """
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC3IUC3_SetBackgroundValue(self, _arg)

    def GetBackgroundValue(self):
        r"""GetBackgroundValue(self) -> unsigned char"""
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC3IUC3_GetBackgroundValue(self)

    def GetLambda(self):
        r"""GetLambda(self) -> double"""
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC3IUC3_GetLambda(self)

    def SetLambda(self, _arg):
        r"""
        SetLambda(self, _arg)

        Parameters
        ----------
        _arg: double

        """
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC3IUC3_SetLambda(self, _arg)

    def GetReverseOrdering(self):
        r"""GetReverseOrdering(self) -> bool"""
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC3IUC3_GetReverseOrdering(self)

    def SetReverseOrdering(self, _arg):
        r"""
        SetReverseOrdering(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC3IUC3_SetReverseOrdering(self, _arg)

    def ReverseOrderingOn(self):
        r"""ReverseOrderingOn(self)"""
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC3IUC3_ReverseOrderingOn(self)

    def ReverseOrderingOff(self):
        r"""ReverseOrderingOff(self)"""
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC3IUC3_ReverseOrderingOff(self)

    def GetAttribute(self):
        r"""GetAttribute(self) -> unsigned int"""
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC3IUC3_GetAttribute(self)

    def SetAttribute(self, *args):
        r"""
        SetAttribute(self, _arg)

        Parameters
        ----------
        _arg: unsigned int

        SetAttribute(self, s)

        Parameters
        ----------
        s: std::string const &

        """
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC3IUC3_SetAttribute(self, *args)

    def SetFeatureImage(self, input):
        r"""
        SetFeatureImage(self, input)

        Parameters
        ----------
        input: itkImageUC3 const *

        """
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC3IUC3_SetFeatureImage(self, input)

    def GetFeatureImage(self):
        r"""GetFeatureImage(self) -> itkImageUC3"""
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC3IUC3_GetFeatureImage(self)

    def SetInput1(self, input):
        r"""
        SetInput1(self, input)

        Parameters
        ----------
        input: itkImageUC3 const *

        """
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC3IUC3_SetInput1(self, input)

    def SetInput2(self, input):
        r"""
        SetInput2(self, input)

        Parameters
        ----------
        input: itkImageUC3 const *

        """
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC3IUC3_SetInput2(self, input)
    __swig_destroy__ = _itkLabelStatisticsOpeningImageFilterPython.delete_itkLabelStatisticsOpeningImageFilterIUC3IUC3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkLabelStatisticsOpeningImageFilterIUC3IUC3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC3IUC3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkLabelStatisticsOpeningImageFilterIUC3IUC3

        Create a new object of the class itkLabelStatisticsOpeningImageFilterIUC3IUC3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkLabelStatisticsOpeningImageFilterIUC3IUC3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkLabelStatisticsOpeningImageFilterIUC3IUC3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkLabelStatisticsOpeningImageFilterIUC3IUC3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkLabelStatisticsOpeningImageFilterIUC3IUC3 in _itkLabelStatisticsOpeningImageFilterPython:
_itkLabelStatisticsOpeningImageFilterPython.itkLabelStatisticsOpeningImageFilterIUC3IUC3_swigregister(itkLabelStatisticsOpeningImageFilterIUC3IUC3)

from itk.support import helpers
import itk.support.types as itkt
from typing import Sequence, Tuple, Union

@helpers.accept_array_like_xarray_torch
def label_statistics_opening_image_filter(*args: itkt.ImageLike,  background_value: int=..., reverse_ordering: bool=..., attribute: Union[int, str]=..., feature_image: itkt.Image=...,**kwargs)-> itkt.ImageSourceReturn:
    """Functional interface for LabelStatisticsOpeningImageFilter"""
    import itk

    kwarg_typehints = { 'background_value':background_value,'reverse_ordering':reverse_ordering,'attribute':attribute,'feature_image':feature_image }
    specified_kwarg_typehints = { k:v for (k,v) in kwarg_typehints.items() if kwarg_typehints[k] is not ... }
    kwargs.update(specified_kwarg_typehints)


    instance = itk.LabelStatisticsOpeningImageFilter.New(*args, **kwargs)

    return instance.__internal_call__()

def label_statistics_opening_image_filter_init_docstring():
    import itk
    from itk.support import template_class

    filter_class = itk.ITKLabelMap.LabelStatisticsOpeningImageFilter
    label_statistics_opening_image_filter.process_object = filter_class
    is_template = isinstance(filter_class, template_class.itkTemplate)
    if is_template:
        filter_object = filter_class.values()[0]
    else:
        filter_object = filter_class

    label_statistics_opening_image_filter.__doc__ = filter_object.__doc__



